==> haskell-hunit-1.6.0.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HUnit
version: 1.6.0.0
id: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
key: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
license: BSD-3-Clause
maintainer: Simon Hengel <sol@typeful.net>
author: Dean Herington
stability: stable
homepage: https://github.com/hspec/HUnit#readme
synopsis: A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.
category: Testing
abi: b175aabb3dd9ae95a14a70d0ded5aa16
exposed: True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text
hidden-modules: Paths_HUnit
import-dirs: /usr/lib/ghc-8.4.3/site-local/HUnit-1.6.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/HUnit-1.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/HUnit-1.6.0.0
hs-libraries: HSHUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
haddock-interfaces: /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html: /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hunit-1.6.0.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HUnit
version: 1.6.0.0
id: HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
key: HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
license: BSD-3-Clause
maintainer: Simon Hengel <sol@typeful.net>
author: Dean Herington
stability: stable
homepage: https://github.com/hspec/HUnit#readme
synopsis: A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.
category: Testing
abi: 959bdf2e7ddc7f6f8f5b9df1594ffecb
exposed: True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text
hidden-modules: Paths_HUnit
import-dirs: /usr/lib/ghc-8.6.1/site-local/HUnit-1.6.0.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/HUnit-1.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/HUnit-1.6.0.0
hs-libraries: HSHUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
depends:
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html: /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
